* NOTE: You need to set the Stata working directory to the path
* where the data file is located.

set more off

clear
quietly infix              ///
  int     year      1-4    ///
  long    serial    5-9    ///
  float   hwtsupp   10-19  ///
  float   cpi99     20-23  ///
  byte    month     24-25  ///
  byte    pernum    26-27  ///
  float   wtsupp    28-37  ///
  float   earnwt    38-47  ///
  byte    nchild    48-48  ///
  byte    nchlt5    49-49  ///
  byte    eldch     50-51  ///
  byte    age       52-53  ///
  byte    sex       54-54  ///
  byte    marst     55-55  ///
  int     educ      56-58  ///
  byte    empstat   59-60  ///
  byte    labforce  61-61  ///
  byte    wkswork1  62-63  ///
  byte    wkswork2  64-64  ///
  byte    uhrswork  65-66  ///
  byte    fullpart  67-67  ///
  float   hourwage  68-71  ///
  long    incwage   72-78  ///
  long    incss     79-83  ///
  long    incretir  84-89  ///
  byte    srcreti1  90-90  ///
  byte    srcreti2  91-91  ///
  byte    whyss1    92-92  ///
  byte    whyss2    93-93  ///
  using `"D:\CPS-IPUMS\FLP_Virginia\cps_00010.dat"'

replace hwtsupp  = hwtsupp  / 10000
replace cpi99    = cpi99    / 1000
replace wtsupp   = wtsupp   / 10000
replace earnwt   = earnwt   / 10000
replace hourwage = hourwage / 100

format hwtsupp  %10.4f
format cpi99    %4.3f
format wtsupp   %10.4f
format earnwt   %10.4f
format hourwage %4.2f

label var year     `"Survey year"'
label var serial   `"Household serial number"'
label var hwtsupp  `"Household weight, Supplement"'
label var cpi99    `"CPI-U adjustment factor to 1999 dollars"'
label var month    `"Month"'
label var pernum   `"Person number in sample unit"'
label var wtsupp   `"Supplement Weight"'
label var earnwt   `"Earnings weight"'
label var nchild   `"Number of own children in household"'
label var nchlt5   `"Number of own children under age 5 in hh"'
label var eldch    `"Age of eldest own child in household"'
label var age      `"Age"'
label var sex      `"Sex"'
label var marst    `"Marital status"'
label var educ     `"Educational attainment recode"'
label var empstat  `"Employment status"'
label var labforce `"Labor force status"'
label var wkswork1 `"Weeks worked last year"'
label var wkswork2 `"Weeks worked last year, intervalled"'
label var uhrswork `"Usual hours worked per week (last yr)"'
label var fullpart `"Worked full or part time last year"'
label var hourwage `"Hourly wage"'
label var incwage  `"Wage and salary income"'
label var incss    `"Social Security income"'
label var incretir `"Retirement income"'
label var srcreti1 `"First source of retirement income"'
label var srcreti2 `"Second source of retirement income"'
label var whyss1   `"First reason for receiving social security income"'
label var whyss2   `"Second reason for receiving social security income"'

label define hwtsupp_lbl 0000000000 `"0000000000"'
label values hwtsupp hwtsupp_lbl

label define month_lbl 01 `"January"'
label define month_lbl 02 `"February"', add
label define month_lbl 03 `"March"', add
label define month_lbl 04 `"April"', add
label define month_lbl 05 `"May"', add
label define month_lbl 06 `"June"', add
label define month_lbl 07 `"July"', add
label define month_lbl 08 `"August"', add
label define month_lbl 09 `"September"', add
label define month_lbl 10 `"October"', add
label define month_lbl 11 `"November"', add
label define month_lbl 12 `"December"', add
label values month month_lbl

label define wtsupp_lbl 0000000000 `"0000000000"'
label values wtsupp wtsupp_lbl

label define earnwt_lbl 0000000000 `"0"'
label values earnwt earnwt_lbl

label define nchild_lbl 0 `"0 children present"'
label define nchild_lbl 1 `"1 child present"', add
label define nchild_lbl 2 `"2"', add
label define nchild_lbl 3 `"3"', add
label define nchild_lbl 4 `"4"', add
label define nchild_lbl 5 `"5"', add
label define nchild_lbl 6 `"6"', add
label define nchild_lbl 7 `"7"', add
label define nchild_lbl 8 `"8"', add
label define nchild_lbl 9 `"9+"', add
label values nchild nchild_lbl

label define nchlt5_lbl 0 `"No children under age 5"'
label define nchlt5_lbl 1 `"1 child under age 5"', add
label define nchlt5_lbl 2 `"2"', add
label define nchlt5_lbl 3 `"3"', add
label define nchlt5_lbl 4 `"4"', add
label define nchlt5_lbl 5 `"5"', add
label define nchlt5_lbl 6 `"6"', add
label define nchlt5_lbl 7 `"7"', add
label define nchlt5_lbl 8 `"8"', add
label define nchlt5_lbl 9 `"9+"', add
label values nchlt5 nchlt5_lbl

label define eldch_lbl 00 `"Less than 1 year old"'
label define eldch_lbl 01 `"1"', add
label define eldch_lbl 02 `"2"', add
label define eldch_lbl 03 `"3"', add
label define eldch_lbl 04 `"4"', add
label define eldch_lbl 05 `"5"', add
label define eldch_lbl 06 `"6"', add
label define eldch_lbl 07 `"7"', add
label define eldch_lbl 08 `"8"', add
label define eldch_lbl 09 `"9"', add
label define eldch_lbl 10 `"10"', add
label define eldch_lbl 11 `"11"', add
label define eldch_lbl 12 `"12"', add
label define eldch_lbl 13 `"13"', add
label define eldch_lbl 14 `"14"', add
label define eldch_lbl 15 `"15"', add
label define eldch_lbl 16 `"16"', add
label define eldch_lbl 17 `"17"', add
label define eldch_lbl 18 `"18"', add
label define eldch_lbl 19 `"19"', add
label define eldch_lbl 20 `"20"', add
label define eldch_lbl 21 `"21"', add
label define eldch_lbl 22 `"22"', add
label define eldch_lbl 23 `"23"', add
label define eldch_lbl 24 `"24"', add
label define eldch_lbl 25 `"25"', add
label define eldch_lbl 26 `"26"', add
label define eldch_lbl 27 `"27"', add
label define eldch_lbl 28 `"28"', add
label define eldch_lbl 29 `"29"', add
label define eldch_lbl 30 `"30"', add
label define eldch_lbl 31 `"31"', add
label define eldch_lbl 32 `"32"', add
label define eldch_lbl 33 `"33"', add
label define eldch_lbl 34 `"34"', add
label define eldch_lbl 35 `"35"', add
label define eldch_lbl 36 `"36"', add
label define eldch_lbl 37 `"37"', add
label define eldch_lbl 38 `"38"', add
label define eldch_lbl 39 `"39"', add
label define eldch_lbl 40 `"40"', add
label define eldch_lbl 41 `"41"', add
label define eldch_lbl 42 `"42"', add
label define eldch_lbl 43 `"43"', add
label define eldch_lbl 44 `"44"', add
label define eldch_lbl 45 `"45"', add
label define eldch_lbl 46 `"46"', add
label define eldch_lbl 47 `"47"', add
label define eldch_lbl 48 `"48"', add
label define eldch_lbl 49 `"49"', add
label define eldch_lbl 50 `"50"', add
label define eldch_lbl 51 `"51"', add
label define eldch_lbl 52 `"52"', add
label define eldch_lbl 53 `"53"', add
label define eldch_lbl 54 `"54"', add
label define eldch_lbl 55 `"55"', add
label define eldch_lbl 56 `"56"', add
label define eldch_lbl 57 `"57"', add
label define eldch_lbl 58 `"58"', add
label define eldch_lbl 59 `"59"', add
label define eldch_lbl 60 `"60"', add
label define eldch_lbl 61 `"61"', add
label define eldch_lbl 62 `"62"', add
label define eldch_lbl 63 `"63"', add
label define eldch_lbl 64 `"64"', add
label define eldch_lbl 65 `"65"', add
label define eldch_lbl 66 `"66"', add
label define eldch_lbl 67 `"67"', add
label define eldch_lbl 68 `"68"', add
label define eldch_lbl 69 `"69"', add
label define eldch_lbl 70 `"70"', add
label define eldch_lbl 71 `"71"', add
label define eldch_lbl 72 `"72"', add
label define eldch_lbl 73 `"73"', add
label define eldch_lbl 74 `"74"', add
label define eldch_lbl 75 `"75"', add
label define eldch_lbl 76 `"76"', add
label define eldch_lbl 77 `"77"', add
label define eldch_lbl 78 `"78"', add
label define eldch_lbl 79 `"79"', add
label define eldch_lbl 80 `"80"', add
label define eldch_lbl 81 `"81"', add
label define eldch_lbl 82 `"82"', add
label define eldch_lbl 83 `"83"', add
label define eldch_lbl 84 `"84"', add
label define eldch_lbl 85 `"85"', add
label define eldch_lbl 86 `"86"', add
label define eldch_lbl 87 `"87"', add
label define eldch_lbl 88 `"88"', add
label define eldch_lbl 89 `"89"', add
label define eldch_lbl 90 `"90"', add
label define eldch_lbl 91 `"91"', add
label define eldch_lbl 92 `"92"', add
label define eldch_lbl 93 `"93"', add
label define eldch_lbl 94 `"94"', add
label define eldch_lbl 95 `"95"', add
label define eldch_lbl 96 `"96"', add
label define eldch_lbl 97 `"97"', add
label define eldch_lbl 98 `"98"', add
label define eldch_lbl 99 `"NIU"', add
label values eldch eldch_lbl

label define age_lbl 00 `"Under 1 year"'
label define age_lbl 01 `"1"', add
label define age_lbl 02 `"2"', add
label define age_lbl 03 `"3"', add
label define age_lbl 04 `"4"', add
label define age_lbl 05 `"5"', add
label define age_lbl 06 `"6"', add
label define age_lbl 07 `"7"', add
label define age_lbl 08 `"8"', add
label define age_lbl 09 `"9"', add
label define age_lbl 10 `"10"', add
label define age_lbl 11 `"11"', add
label define age_lbl 12 `"12"', add
label define age_lbl 13 `"13"', add
label define age_lbl 14 `"14"', add
label define age_lbl 15 `"15"', add
label define age_lbl 16 `"16"', add
label define age_lbl 17 `"17"', add
label define age_lbl 18 `"18"', add
label define age_lbl 19 `"19"', add
label define age_lbl 20 `"20"', add
label define age_lbl 21 `"21"', add
label define age_lbl 22 `"22"', add
label define age_lbl 23 `"23"', add
label define age_lbl 24 `"24"', add
label define age_lbl 25 `"25"', add
label define age_lbl 26 `"26"', add
label define age_lbl 27 `"27"', add
label define age_lbl 28 `"28"', add
label define age_lbl 29 `"29"', add
label define age_lbl 30 `"30"', add
label define age_lbl 31 `"31"', add
label define age_lbl 32 `"32"', add
label define age_lbl 33 `"33"', add
label define age_lbl 34 `"34"', add
label define age_lbl 35 `"35"', add
label define age_lbl 36 `"36"', add
label define age_lbl 37 `"37"', add
label define age_lbl 38 `"38"', add
label define age_lbl 39 `"39"', add
label define age_lbl 40 `"40"', add
label define age_lbl 41 `"41"', add
label define age_lbl 42 `"42"', add
label define age_lbl 43 `"43"', add
label define age_lbl 44 `"44"', add
label define age_lbl 45 `"45"', add
label define age_lbl 46 `"46"', add
label define age_lbl 47 `"47"', add
label define age_lbl 48 `"48"', add
label define age_lbl 49 `"49"', add
label define age_lbl 50 `"50"', add
label define age_lbl 51 `"51"', add
label define age_lbl 52 `"52"', add
label define age_lbl 53 `"53"', add
label define age_lbl 54 `"54"', add
label define age_lbl 55 `"55"', add
label define age_lbl 56 `"56"', add
label define age_lbl 57 `"57"', add
label define age_lbl 58 `"58"', add
label define age_lbl 59 `"59"', add
label define age_lbl 60 `"60"', add
label define age_lbl 61 `"61"', add
label define age_lbl 62 `"62"', add
label define age_lbl 63 `"63"', add
label define age_lbl 64 `"64"', add
label define age_lbl 65 `"65"', add
label define age_lbl 66 `"66"', add
label define age_lbl 67 `"67"', add
label define age_lbl 68 `"68"', add
label define age_lbl 69 `"69"', add
label define age_lbl 70 `"70"', add
label define age_lbl 71 `"71"', add
label define age_lbl 72 `"72"', add
label define age_lbl 73 `"73"', add
label define age_lbl 74 `"74"', add
label define age_lbl 75 `"75"', add
label define age_lbl 76 `"76"', add
label define age_lbl 77 `"77"', add
label define age_lbl 78 `"78"', add
label define age_lbl 79 `"79"', add
label define age_lbl 80 `"80"', add
label define age_lbl 81 `"81"', add
label define age_lbl 82 `"82"', add
label define age_lbl 83 `"83"', add
label define age_lbl 84 `"84"', add
label define age_lbl 85 `"85"', add
label define age_lbl 86 `"86"', add
label define age_lbl 87 `"87"', add
label define age_lbl 88 `"88"', add
label define age_lbl 89 `"89"', add
label define age_lbl 90 `"90 (90+, 1988-2002)"', add
label define age_lbl 91 `"91"', add
label define age_lbl 92 `"92"', add
label define age_lbl 93 `"93"', add
label define age_lbl 94 `"94"', add
label define age_lbl 95 `"95"', add
label define age_lbl 96 `"96"', add
label define age_lbl 97 `"97"', add
label define age_lbl 98 `"98"', add
label define age_lbl 99 `"99+"', add
label values age age_lbl

label define sex_lbl 1 `"Male"'
label define sex_lbl 2 `"Female"', add
label define sex_lbl 9 `"NIU"', add
label values sex sex_lbl

label define marst_lbl 1 `"Married, spouse present"'
label define marst_lbl 2 `"Married, spouse absent"', add
label define marst_lbl 3 `"Separated"', add
label define marst_lbl 4 `"Divorced"', add
label define marst_lbl 5 `"Widowed"', add
label define marst_lbl 6 `"Never married/single"', add
label define marst_lbl 9 `"Unknown"', add
label values marst marst_lbl

label define educ_lbl 000 `"NIU or no schooling"'
label define educ_lbl 001 `"NIU"', add
label define educ_lbl 002 `"None or preschool"', add
label define educ_lbl 010 `"Grades 1, 2, 3, or 4"', add
label define educ_lbl 011 `"Grade 1"', add
label define educ_lbl 012 `"Grade 2"', add
label define educ_lbl 013 `"Grade 3"', add
label define educ_lbl 014 `"Grade 4"', add
label define educ_lbl 020 `"Grades 5 or 6"', add
label define educ_lbl 021 `"Grade 5"', add
label define educ_lbl 022 `"Grade 6"', add
label define educ_lbl 030 `"Grades 7 or 8"', add
label define educ_lbl 031 `"Grade 7"', add
label define educ_lbl 032 `"Grade 8"', add
label define educ_lbl 040 `"Grade 9"', add
label define educ_lbl 050 `"Grade 10"', add
label define educ_lbl 060 `"Grade 11"', add
label define educ_lbl 070 `"Grade 12"', add
label define educ_lbl 071 `"12th grade, no diploma"', add
label define educ_lbl 072 `"12th grade, diploma unclear"', add
label define educ_lbl 073 `"High school diploma or equivalent"', add
label define educ_lbl 080 `"1 year of college"', add
label define educ_lbl 081 `"Some college but no degree"', add
label define educ_lbl 090 `"2 years of college"', add
label define educ_lbl 091 `"Associate's degree, occupational/vocational program"', add
label define educ_lbl 092 `"Associate's degree, academic program"', add
label define educ_lbl 100 `"3 years of college"', add
label define educ_lbl 110 `"4 years of college"', add
label define educ_lbl 111 `"Bachelor's degree"', add
label define educ_lbl 120 `"5+ years of college"', add
label define educ_lbl 121 `"5 years of college"', add
label define educ_lbl 122 `"6+ years of college"', add
label define educ_lbl 123 `"Master's degree"', add
label define educ_lbl 124 `"Professional school degree"', add
label define educ_lbl 125 `"Doctorate degree"', add
label define educ_lbl 999 `"Missing/Unknown"', add
label values educ educ_lbl

label define empstat_lbl 00 `"NIU"'
label define empstat_lbl 01 `"Armed Forces"', add
label define empstat_lbl 10 `"At work"', add
label define empstat_lbl 12 `"Has job, not at work last week"', add
label define empstat_lbl 20 `"Unemployed"', add
label define empstat_lbl 21 `"Unemployed, experienced worker"', add
label define empstat_lbl 22 `"Unemployed, new worker"', add
label define empstat_lbl 30 `"Not in labor force"', add
label define empstat_lbl 31 `"NILF, housework"', add
label define empstat_lbl 32 `"NILF, unable to work"', add
label define empstat_lbl 33 `"NILF, school"', add
label define empstat_lbl 34 `"NILF, other"', add
label define empstat_lbl 35 `"NILF, unpaid, lt 15 hours"', add
label values empstat empstat_lbl

label define labforce_lbl 0 `"NIU"'
label define labforce_lbl 1 `"No, not in the labor force"', add
label define labforce_lbl 2 `"Yes, in the labor force"', add
label values labforce labforce_lbl

label define wkswork1_lbl 00 `"NIU"'
label define wkswork1_lbl 01 `"1 week"', add
label define wkswork1_lbl 02 `"2 weeks"', add
label define wkswork1_lbl 03 `"3 weeks"', add
label define wkswork1_lbl 04 `"4 weeks"', add
label define wkswork1_lbl 05 `"5 weeks"', add
label define wkswork1_lbl 06 `"6 weeks"', add
label define wkswork1_lbl 07 `"7 weeks"', add
label define wkswork1_lbl 08 `"8 weeks"', add
label define wkswork1_lbl 09 `"9 weeks"', add
label define wkswork1_lbl 10 `"10 weeks"', add
label define wkswork1_lbl 11 `"11 weeks"', add
label define wkswork1_lbl 12 `"12 weeks"', add
label define wkswork1_lbl 13 `"13 weeks"', add
label define wkswork1_lbl 14 `"14 weeks"', add
label define wkswork1_lbl 15 `"15 weeks"', add
label define wkswork1_lbl 16 `"16 weeks"', add
label define wkswork1_lbl 17 `"17 weeks"', add
label define wkswork1_lbl 18 `"18 weeks"', add
label define wkswork1_lbl 19 `"19 weeks"', add
label define wkswork1_lbl 20 `"20 weeks"', add
label define wkswork1_lbl 21 `"21 weeks"', add
label define wkswork1_lbl 22 `"22 weeks"', add
label define wkswork1_lbl 23 `"23 weeks"', add
label define wkswork1_lbl 24 `"24 weeks"', add
label define wkswork1_lbl 25 `"25 weeks"', add
label define wkswork1_lbl 26 `"26 weeks"', add
label define wkswork1_lbl 27 `"27 weeks"', add
label define wkswork1_lbl 28 `"28 weeks"', add
label define wkswork1_lbl 29 `"29 weeks"', add
label define wkswork1_lbl 30 `"30 weeks"', add
label define wkswork1_lbl 31 `"31 weeks"', add
label define wkswork1_lbl 32 `"32 weeks"', add
label define wkswork1_lbl 33 `"33 weeks"', add
label define wkswork1_lbl 34 `"34 weeks"', add
label define wkswork1_lbl 35 `"35 weeks"', add
label define wkswork1_lbl 36 `"36 weeks"', add
label define wkswork1_lbl 37 `"37 weeks"', add
label define wkswork1_lbl 38 `"38 weeks"', add
label define wkswork1_lbl 39 `"39 weeks"', add
label define wkswork1_lbl 40 `"40 weeks"', add
label define wkswork1_lbl 41 `"41 weeks"', add
label define wkswork1_lbl 42 `"42 weeks"', add
label define wkswork1_lbl 43 `"43 weeks"', add
label define wkswork1_lbl 44 `"44 weeks"', add
label define wkswork1_lbl 45 `"45 weeks"', add
label define wkswork1_lbl 46 `"46 weeks"', add
label define wkswork1_lbl 47 `"47 weeks"', add
label define wkswork1_lbl 48 `"48 weeks"', add
label define wkswork1_lbl 49 `"49 weeks"', add
label define wkswork1_lbl 50 `"50 weeks"', add
label define wkswork1_lbl 51 `"51 weeks"', add
label define wkswork1_lbl 52 `"52 weeks"', add
label values wkswork1 wkswork1_lbl

label define wkswork2_lbl 0 `"NIU"'
label define wkswork2_lbl 1 `"1-13 weeks"', add
label define wkswork2_lbl 2 `"14-26 weeks"', add
label define wkswork2_lbl 3 `"27-39 weeks"', add
label define wkswork2_lbl 4 `"40-47 weeks"', add
label define wkswork2_lbl 5 `"48-49 weeks"', add
label define wkswork2_lbl 6 `"50-52 weeks"', add
label define wkswork2_lbl 9 `"Missing data"', add
label values wkswork2 wkswork2_lbl

label define uhrswork_lbl 00 `"NIU"'
label define uhrswork_lbl 01 `"1 hour"', add
label define uhrswork_lbl 02 `"2 hours"', add
label define uhrswork_lbl 03 `"3 hours"', add
label define uhrswork_lbl 04 `"4 hours"', add
label define uhrswork_lbl 05 `"5 hours"', add
label define uhrswork_lbl 06 `"6 hours"', add
label define uhrswork_lbl 07 `"7 hours"', add
label define uhrswork_lbl 08 `"8 hours"', add
label define uhrswork_lbl 09 `"9 hours"', add
label define uhrswork_lbl 10 `"10 hours"', add
label define uhrswork_lbl 11 `"11 hours"', add
label define uhrswork_lbl 12 `"12 hours"', add
label define uhrswork_lbl 13 `"13 hours"', add
label define uhrswork_lbl 14 `"14 hours"', add
label define uhrswork_lbl 15 `"15 hours"', add
label define uhrswork_lbl 16 `"16 hours"', add
label define uhrswork_lbl 17 `"17 hours"', add
label define uhrswork_lbl 18 `"18 hours"', add
label define uhrswork_lbl 19 `"19 hours"', add
label define uhrswork_lbl 20 `"20 hours"', add
label define uhrswork_lbl 21 `"21 hours"', add
label define uhrswork_lbl 22 `"22 hours"', add
label define uhrswork_lbl 23 `"23 hours"', add
label define uhrswork_lbl 24 `"24 hours"', add
label define uhrswork_lbl 25 `"25 hours"', add
label define uhrswork_lbl 26 `"26 hours"', add
label define uhrswork_lbl 27 `"27 hours"', add
label define uhrswork_lbl 28 `"28 hours"', add
label define uhrswork_lbl 29 `"29 hours"', add
label define uhrswork_lbl 30 `"30 hours"', add
label define uhrswork_lbl 31 `"31 hours"', add
label define uhrswork_lbl 32 `"32 hours"', add
label define uhrswork_lbl 33 `"33 hours"', add
label define uhrswork_lbl 34 `"34 hours"', add
label define uhrswork_lbl 35 `"35 hours"', add
label define uhrswork_lbl 36 `"36 hours"', add
label define uhrswork_lbl 37 `"37 hours"', add
label define uhrswork_lbl 38 `"38 hours"', add
label define uhrswork_lbl 39 `"39 hours"', add
label define uhrswork_lbl 40 `"40 hours"', add
label define uhrswork_lbl 41 `"41 hours"', add
label define uhrswork_lbl 42 `"42 hours"', add
label define uhrswork_lbl 43 `"43 hours"', add
label define uhrswork_lbl 44 `"44 hours"', add
label define uhrswork_lbl 45 `"45 hours"', add
label define uhrswork_lbl 46 `"46 hours"', add
label define uhrswork_lbl 47 `"47 hours"', add
label define uhrswork_lbl 48 `"48 hours"', add
label define uhrswork_lbl 49 `"49 hours"', add
label define uhrswork_lbl 50 `"50 hours"', add
label define uhrswork_lbl 51 `"51 hours"', add
label define uhrswork_lbl 52 `"52 hours"', add
label define uhrswork_lbl 53 `"53 hours"', add
label define uhrswork_lbl 54 `"54 hours"', add
label define uhrswork_lbl 55 `"55 hours"', add
label define uhrswork_lbl 56 `"56 hours"', add
label define uhrswork_lbl 57 `"57 hours"', add
label define uhrswork_lbl 58 `"58 hours"', add
label define uhrswork_lbl 59 `"59 hours"', add
label define uhrswork_lbl 60 `"60 hours"', add
label define uhrswork_lbl 61 `"61 hours"', add
label define uhrswork_lbl 62 `"62 hours"', add
label define uhrswork_lbl 63 `"63 hours"', add
label define uhrswork_lbl 64 `"64 hours"', add
label define uhrswork_lbl 65 `"65 hours"', add
label define uhrswork_lbl 66 `"66 hours"', add
label define uhrswork_lbl 67 `"67 hours"', add
label define uhrswork_lbl 68 `"68 hours"', add
label define uhrswork_lbl 69 `"69 hours"', add
label define uhrswork_lbl 70 `"70 hours"', add
label define uhrswork_lbl 71 `"71 hours"', add
label define uhrswork_lbl 72 `"72 hours"', add
label define uhrswork_lbl 73 `"73 hours"', add
label define uhrswork_lbl 74 `"74 hours"', add
label define uhrswork_lbl 75 `"75 hours"', add
label define uhrswork_lbl 76 `"76 hours"', add
label define uhrswork_lbl 77 `"77 hours"', add
label define uhrswork_lbl 78 `"78 hours"', add
label define uhrswork_lbl 79 `"79 hours"', add
label define uhrswork_lbl 80 `"80 hours"', add
label define uhrswork_lbl 81 `"81 hours"', add
label define uhrswork_lbl 82 `"82 hours"', add
label define uhrswork_lbl 83 `"83 hours"', add
label define uhrswork_lbl 84 `"84 hours"', add
label define uhrswork_lbl 85 `"85 hours"', add
label define uhrswork_lbl 86 `"86 hours"', add
label define uhrswork_lbl 87 `"87 hours"', add
label define uhrswork_lbl 88 `"88 hours"', add
label define uhrswork_lbl 89 `"89 hours"', add
label define uhrswork_lbl 90 `"90 hours"', add
label define uhrswork_lbl 91 `"91 hours"', add
label define uhrswork_lbl 92 `"92 hours"', add
label define uhrswork_lbl 93 `"93 hours"', add
label define uhrswork_lbl 94 `"94 hours"', add
label define uhrswork_lbl 95 `"95 hours"', add
label define uhrswork_lbl 96 `"96 hours"', add
label define uhrswork_lbl 97 `"97 hours"', add
label define uhrswork_lbl 98 `"98 hours"', add
label define uhrswork_lbl 99 `"99 hours plus"', add
label values uhrswork uhrswork_lbl

label define fullpart_lbl 0 `"NIU"'
label define fullpart_lbl 1 `"Full-time"', add
label define fullpart_lbl 2 `"Part-time"', add
label define fullpart_lbl 9 `"Unknown"', add
label values fullpart fullpart_lbl

label define hourwage_lbl 9999 `"NIU"'
label values hourwage hourwage_lbl

label define incwage_lbl 9999997 `"9999997"'
label define incwage_lbl 9999999 `"9999999"', add
label values incwage incwage_lbl

label define srcreti1_lbl 0 `"NIU"'
label define srcreti1_lbl 1 `"Company or Union  pension"', add
label define srcreti1_lbl 2 `"Federal Government retirement Pension"', add
label define srcreti1_lbl 3 `"US Military retirement pension"', add
label define srcreti1_lbl 4 `"State or local Govt retirement pension"', add
label define srcreti1_lbl 5 `"US Railroad retirement pension"', add
label define srcreti1_lbl 6 `"Regular payments from annuities or paid-up insurance policies"', add
label define srcreti1_lbl 7 `"Regular payments from IRA, KEOGH, or 401K accounts"', add
label define srcreti1_lbl 8 `"Other or don't know"', add
label values srcreti1 srcreti1_lbl

label define srcreti2_lbl 0 `"NIU"'
label define srcreti2_lbl 1 `"Company or Union  pension"', add
label define srcreti2_lbl 2 `"Federal Government retirement Pension"', add
label define srcreti2_lbl 3 `"US Military retirement pension"', add
label define srcreti2_lbl 4 `"State or local Govt retirement pension"', add
label define srcreti2_lbl 5 `"US Railroad retirement pension"', add
label define srcreti2_lbl 6 `"Regular payments from annuities or paid-up insurance policies"', add
label define srcreti2_lbl 7 `"Regular payments from IRA, KEOGH, or 401K accounts"', add
label define srcreti2_lbl 8 `"Other or do not know"', add
label values srcreti2 srcreti2_lbl

label define whyss1_lbl 0 `"NIU"'
label define whyss1_lbl 1 `"Retired"', add
label define whyss1_lbl 2 `"Disabled (adult or child)"', add
label define whyss1_lbl 3 `"Widowed"', add
label define whyss1_lbl 4 `"Spouse"', add
label define whyss1_lbl 5 `"Surviving child"', add
label define whyss1_lbl 6 `"Dependent child"', add
label define whyss1_lbl 7 `"On behalf of surviving, dependent, or disabled child(ren)"', add
label define whyss1_lbl 8 `"Other (adult or child)"', add
label values whyss1 whyss1_lbl

label define whyss2_lbl 0 `"NIU"'
label define whyss2_lbl 1 `"Retired"', add
label define whyss2_lbl 2 `"Disabled (adult or child)"', add
label define whyss2_lbl 3 `"Widowed"', add
label define whyss2_lbl 4 `"Spouse"', add
label define whyss2_lbl 5 `"Surviving child"', add
label define whyss2_lbl 6 `"Dependent child"', add
label define whyss2_lbl 7 `"On behalf of surviving, dependent, or disabled child(ren)"', add
label define whyss2_lbl 8 `"Other (adult or child)"', add
label values whyss2 whyss2_lbl


save "D:\CPS-IPUMS\FLP_Virginia\cps_00010.dta"