
clear matrix
clear
set more off
capture log close
set mem 200m


*local file "base"



infile i t yrsexp stat couple retage qnode cnode agekid ntH tipoMARR experien saving earnm partcash wagef cons socsecm piaf socsecf penf euler2 taxm taxf taxhusband taxwife fix using sample.out


****************************************************************************************************************************

*NOTAS:
*1*husband/wife earnings exported from simulate.f90 are GROSS, including social security contribution by the employer


*2*before ntmin     :penf is own-worker pension and socsecf is max(spousal, own)
*after ntmin        :penf=max(spousal,own-pension), socsecf= penf OR it is updated if woman gets widow and survivor is larger
*tipoMARR           :only actual one after nt, in all other periods is set equal to 1000
 
*3*taxm/taxf: payroll tax, tashusband/taxwife: federal tax

****************************************************************************************************************************

label define tipoMARRl 1 "worker" 2 "worker+spousal" 3 "spousal" 
label values tipoMARR tipoMARRl


gen nt=41
gen firstretage=62
gen offage=66
gen lastretage=66
gen lastworkage=65

gen lastworkageH=ntH + 24
gen firstretageH=ntH+1 + 24

gen firstageAIME=lastworkageH - 35


gen nc=35


gen hoursfix=2000
gen phoursfix=2000


gen earnf=wagef*hoursfix if stat==1
replace earnf=0 if stat==0

gen age= t + 24

gen agekid2=agekid+3
gen years1=t- agekid
gen years2=t- agekid2


gen ageg2=1 if age<35
replace ageg2=2 if age>=35 & age<45
replace ageg2=3 if age>=45 & age<55
replace ageg2=4 if age>=55 & age<65
replace ageg2=5 if age>=65 & age<75
replace ageg2=6 if age>=75 

gen child04=0
gen child517=0
replace child04   =1 if years1>=0 & years1<5
replace child517 =1 if years1>=5 & years1<18
replace child04    =child04   +1 if years2>=0 & years2<5
replace child517  =child517 +1 if years2>=5 & years2<18
gen child=child04+child517




gen learnm=log(earnm)
gen lwagef=log(wagef)


gen experien2=experien*experien

gen earn=earnf + earnm


sort i t
*I assume that 1.5% is the interest rate net of a 20% capital income tax

gen inc=earn + socsecf + socsecm + saving[_n-1]*0.015/0.8

gen taxsav=saving[_n-1]*0.015*0.2/0.8
gen avtaxinc=(taxhusband+taxwife+taxsav)/inc

egen meanhholdinc=mean(inc) 
gen mulinc=inc/meanhholdinc


*this is the present value of social security pension under the benchmark system
gen inc2=(socsecf + socsecm)/(1.015^(t-1)) 
by i:egen pvi2=sum(inc2)

*this is the present value of social security pension under the benchmark system EXCLUDING wife's income
gen inc3=(socsecm)/(1.015^(t-1)) 
by i:egen pvi3=sum(inc3)



sort i t
by i:gen aux=sum(stat)
by i:gen totstat=aux[_N]
gen Itotstat=(totstat>0)
drop aux




*save sample_`file'.dta,replace
save sample.dta,replace


**********************************************************************************************************************
*COUNTERFACTUAL PROFILES

*recover husband shock
*0.05d0      !earnings growth for primary earner                              
*-0.00044d0   !earnings growth for primary earner 
gen a1=0.05
gen a2=-0.00044
gen hgrowth=exp(a1*age+a2*age*age)
gen pxw=earnm/hgrowth if age<=lastworkageH


gen obswage=wagef if stat==1
gen wagem=earnm/phoursfix
gen lwagem=log(wagem)

*recover wive shock
gen xw=wagef/exp(0.01*(experien-1)-0.00014*(experien-1)*(experien-1))

gen growthm=exp(a1*age+a2*age*age)
gen growthf=exp(0.01*(t-1)-0.00014*(t-1)*(t-1))

*THIS GIVES SAME PROFILE THAN MEN IF WORKING EVERY PERIOD
*gen growthf=exp(0.027*(t-1)-0.00014*(t-1)*(t-1))

gen aux=growthm if t==1
egen growthmMIN=min(aux)
drop aux
gen aux=growthf if t==1
egen growthfMIN=min(aux)
drop aux
replace growthm=growthm/growthmMIN
replace growthf=growthf/growthfMIN


*preserve
*keep if t<40
*collapse growthm growthf,by(t)
*line growthm growthf t, title("Compare Human Capital Technologies")
*COMMENT: there is an exogenous gender gap against women: even working as much as men, women wages grow less
*restore

**********************************************************************************************************************
*THIS IS TO FIND PARAMETERS FOR HUSBAND EARNINGS GROWTH, ONLY USED IN THE BEGINNING to calibrate

*gen aa1=0.05
*gen aa2=-0.00044
*gen earnm2=pxw*exp(aa1*age + aa2*age*age) 

*sort i age
*by i:gen growth2=earnm2[_n]/earnm2[_n-1]-1

*sum growth2 if age<=35
*sum growth2 if age<=lastworkageH

*sum earnm2 if age<=lastworkageH

*keep if age<60
*collapse earnm2,by(age)
*line earnm2 age


**********************************************************************************************************************

log using sample.log,replace

**********************************************************************************************************************
*HOUSEHOLD INCOME

sum inc,d

*Hholds 65 or younger
sum earn if ageg2<=4,d

sum inc if ageg2<=4,d



*DEMOGRAPHICS

*fraction of widows

gen womentype=1 if couple==1
replace womentype=2 if couple==2

tab womentype if age>=lastworkage
tab womentype if age==lastworkage
tab womentype if age>=lastworkage & age<75
tab womentype if age>=75

**********************************************************************************************************************
*LABOUR MARKET

*by age group
sum stat if age>=25 & age<=64
sum stat if age>=25 & age<=29
sum stat if age>=30 & age<=34
sum stat if age>=35 & age<=39
sum stat if age>=40 & age<=44
sum stat if age>=45 & age<=49
sum stat if age>=50 & age<=54
sum stat if age>=55 & age<=59
sum stat if age>=60 & age<=65

*by age
sort age
table age,c(mean stat)


*plot profile
preserve
collapse stat, by(age)

sort age
merge 1:1 age using Life_Cycle_Profile_part_US.dta

keep if age<=65

twoway (line stat age) (line part age, lpattern(dash) ), ylabel (0(0.10)0.80) xlabel(25(10)65) legend (lab(1 "Model"))  legend(lab(2 "Data")) title("") ytitle("") xtitle("Age") graphregion( color(white )  ) saving(part.gph,replace) 
graph export part.pdf, replace
restore


*wage growth
sort i t
by i:gen growth_f=wagef/wagef[_n-1]-1 if stat==1 & stat[_n-1]==1
by i:gen growth_m=earnm/earnm[_n-1]-1 

sum growth_f growth_m if age>=25 & age<=35
sum growth_f growth_m if age>=35 & age<=lastworkageH

*standard deviation of log female wages
sum lwagef if stat==1


*wage gender gap
egen male25=mean(earnm/phoursfix) if age==25 
egen female25=mean(wagef) if age==25
gen gap25=female25/male25 

egen male=mean(earnm/phoursfix) if age>=25 & age<=lastworkageH
egen female=mean(wagef) if stat==1 &age>=25 &  age<=lastworkageH
gen gap=female/male 
sum male female gap gap25 


*earnings

sum earnm if age<=lastworkageH,d
sum earnf if age<=lastworkage ,d
sum wagef if age<=lastworkage & stat==1,d

sum earnm if age>=45 & age<=55,d
sum earnf if age>=45 & age<=55 & stat==1,d




*mincer wage equation
regress lwagef experien experien2 if stat==1
regress lwagef experien experien2 if stat==1 & age>=30 
regress lwagef experien experien2 if stat==1 & age<=59
regress lwagef experien experien2 if stat==1 & age>=30 & age<=59
regress lwagef experien experien2 if stat==1 & age>=39 & age<=59


*participation decision
sort i t
by i:gen lagstat=stat[_n-1]
regress stat learnm
regress stat learnm age child04 child517
regress stat learnm  child04 child517



*years of experience
sum yrsexp  Itotstat if t==nt
sum yrsexp if t==nt & totstat>1,d
sum yrsexp if age==60 & totstat>1,d
sum yrsexp if t==nt,d
tab yrsexp if t==nt

*correlation of experience and husband earnings at t=ntmin
pwcorr yrsexp earnm if age==lastworkageH
pwcorr yrsexp earnm if age==lastworkageH & yrsexp>1

sort earnm
xtile earnmq=earnm if age==lastworkageH,nq(5)
sort earnmq
table earnmq, c(mean earnm mean yrsexp)



*positive self-selection
table age,c(mean wagef mean obswage)





*aveage individual earnings in the economy
gen indivearn=(earnf+earnm)/2 if stat==1
replace indivearn=earnm if stat==0
sum indivearn if t<40


**********************************************************************************************************************
*ASSETS


*assets by age
sort ageg2
sum saving if couple==1,d
table ageg2 if couple==1,c(median saving mean saving)



*assets by income 55-65
preserve
keep if ageg2==4
sum saving,d
sort earn
xtile incq=earn,nq(5)
sort incq
table incq, c(mean earn median earn median saving)
restore


*assets by income 55-65 if earn>0
preserve
keep if ageg2==4
keep if earn>0
sum saving,d
sort earn
xtile incq=earn,nq(5)
sort incq
table incq, c(mean earn median earn median saving)
restore


**********************************************************************************************************************
*PENSIONS

*CALCULATE THE COEFFICIENTS FOR THE APPROXIMATION OF HUSBAND PIA

gen lastpxw_t=pxw if age==lastworkageH


sort i
by i:egen lastpxw=min(lastpxw_t)
gen earnmSIM=lastpxw*hgrowth

*build real PIA & PIA based on the last shock
sort i 
**by i:egen e35=mean(earnm)  if age<=lastworkageH & age>30
**by i:egen e35SIM=mean(earnmSIM)  if age<=lastworkageH & age>30

by i:egen e35=mean(earnm)  if age<=lastworkageH & age>=firstageAIME
by i:egen e35SIM=mean(earnmSIM)  if age<=lastworkageH & age>=firstageAIME


*regression to predict real PIA based on PIA based on the last shock
gen le35=log(e35)
gen le35SIM=log(e35SIM)

reg le35 le35SIM if age==lastworkageH
gen b0=_b[_cons]
gen b1=_b[le35SIM]

*build approximation of PIA using PIA with the last shock and coef from regressions
gen piamXX=exp(b0+b1*le35SIM)


*compare real PIA with approximation
sum e35 piamXX if age==lastworkageH,d


*CHECK PIA APPROXIMATION FOR FEMALES

sort i 
by i:egen e35f=mean(earnf)  if age<firstretage & age>=(firstretage-nc)


*compare real PIA with approximation
sum e35f if e35f>0 & age==firstretage-1 & experien>10,d
sum piaf if piaf>0 & age==firstretage,d


gen lastxw=xw if age==firstretage-1
gen Ixw=xw if stat==1
sort i
by i:egen avxw=mean(Ixw)
gen llastxw=log(lastxw)
gen lavxw=log(avxw)

reg lavxw llastxw

**********************************************************************************************************************
*MALE PENSIONS DISTRIBUTION

sum socsecm if age>=firstretageH & (couple==1 | couple==3),d


**********************************************************************************************************************
*FEMALE PENSION TYPE AND PENSIONS DISTRIBUTION

preserve
keep if age>=firstretage
keep if couple<3

*NOTE: note that tipoMARR is only reported after nt, so below
*we are reporting distribution of pension only for 
*individuals 66 or older (these pension already incorporate 
*the upward adjustment of pension because of pensiones withhold 
*from claiming age to full retirement age

*MARRIED WOMEN (to compare with CPS) TYPE OF PENSION
tab tipoMARR if couple==1 & tipoMARR<100


*MARRIED WOMEN (to compare with CPS) PENSION DISTRIBUTION BY TYPE OF PENSION
sum socsecf if age>=lastretage,d
sum socsecf if couple==1 & tipoMARR==1,d
sum socsecf if couple==1 & tipoMARR>1 & tipoMARR<100,d




*WIDOWS PENSION DISTRIBUTION 
sum socsecf if  couple==2 ,d

*FRACTION OF WIDOWS WITHOUT PENSION
gen Isocsecf=(socsecf>0) 
sort couple
by couple:tab Isocsecf if age>=offage



*COMPARE PRESENT VALUE OF INCOME (up to woman death) WITH AND WITHOUT SPOUSAL/SURVIVOR for women who are not eligible
sum pvi2 pvi3 if tipoMARR>1 & tipoMARR<100 & age==lastretage

restore




****************************************************************************************************
*INEQUALITY 

preserve

keep if couple<3

gen socsec=socsecm+socsecf

keep if t>nt
ineqdec0 socsec
ineqdec0 cons
ineqdec0 saving

sum socsecm socsecf socsec cons saving
sum socsecm socsec if couple==1



ineqdec0 socsec if couple==1 
ineqdec0 socsec if couple==2
*ineqdec0 socsec if couple==3


restore



****************************************************************************************************
*REVENEUS AND EXPENDITURE

egen expenditure1=sum(socsecf)
egen expenditure2=sum(socsecm)
gen expen=(expenditure1+expenditure2)/1000000



egen ssrev1=sum(taxf)
egen ssrev2=sum(taxm)
gen ssrev=(ssrev1+ssrev2)/1000000


egen fedrev1=sum(taxwife)
egen fedrev2=sum(taxhusb)
gen fedrev=(fedrev1+fedrev2)/1000000


sum  ssrev1 ssrev2  fedrev1 fedrev2 expen ssrev fedrev




****************************************************************************************************
*TAXES: average tax rate for different multiples of net of payroll tax-household income

sum avtaxinc if mulinc>0.95 & mulinc<1.05 
sum avtaxinc if mulinc>1.95 & mulinc<2.05
sum avtaxinc if mulinc>2.95 & mulinc<3.05
sum avtaxinc if mulinc>3.95 & mulinc<4.05


log close









*end














