!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
module equations

!this module calculates the value function given the level of consumption (if unemployed)
!or given the level of within period spending (if employed)

use params
use subrout
use wageproc
use bisection
use maknls
!!USE nag_nlp
!!USE nag_uv_min
use summaryindex
use makutility

implicit none

double precision, private :: ax, bx, cx
integer, private ::  ier, xtonon, xtoemp

integer, parameter:: np=2

double precision, private:: valatmin, valatmineps,valatmax,valatmaxeps

double precision aux, maxcon, mincon, nlin_upper(1) , nlin_lower(1), x_lower(2),x_upper(2), &
     lin_lower(1), lin_upper(1), avals(1,2), axx, cxx

integer iter, num_nlin_con, num_lin_con

character (24) restime

!!!!!for powell routines at end of module
    integer, parameter :: nopars=1, NNMAX=20,ITMAXP=200
    integer, private :: ncom
    double precision, private ::  pcom(NNMAX),xicom(NNMAX)
!!!!!



contains


subroutine valnon(valuenon,connon)	 !solving for optimal consumption given not working at t=1,nt

double precision connon, valuenon, valuebit, connon2, valuenon2, piaf, penf, penm, it1, it2

integer penalty
	
	!	in the non-work section, withnon = connon (avoids problem with fixed cost and value of leis

	!algorithm for solving for optimal value function at asset etc.
	! try using "golden" minimisation routine - does not require derivatives


	
	if(age.lt.nt.and.noexp.gt.1)then
		xtonon = max(mapping(age,xvalue,0),1)
	else
		xtonon = 1
	endif


	cash = partcash
	
	ax = minass/2.d0
	cx = max(cash + mininc(xtonon,age)-minass*0.25d0,minass)				
	bx = cx*0.6d0
	
	!perhaps need to check that these consumption levels are ok

	if (borrowdum.le.1) then  !ie saving (and maybe borrowing) allowed 
		
          valatmin = unempfun(ax)
          valatmineps = unempfun(ax*eps1)
          valatmax = unempfun(cx)
          valatmaxeps = unempfun(cx*eps)

          if (valatmin.lt.valatmineps) then !stay at min point

               valuenon = - valatmin
               connon   = ax
            

          elseif (valatmax.lt.valatmaxeps) then ! stay at max point

               valuenon = - valatmax
               connon   = cx
               
            
               
          elseif (cx-ax.lt.1.d-7) then 
          
               valuenon = - valatmaxeps
               connon   = cx*eps              
          
          else

   		 valuenon = golden(ax,bx,cx,unempfun,connon)
	     valuenon = - valuenon !solves for min of negative objective

		     
          endif

	else  !no borrowing or saving

			connon		= partcash
			valuenon	= - unempfun(connon)

	endif



			
end subroutine valnon





! ************************************************
subroutine valret(valueret,conret)	 !solving for optimal consumption given not working

double precision conret, valueret, valuebit, aux
	
	!	in the non-work section, withnon = connon (avoids problem with fixed cost and value of leis

	!algorithm for solving for optimal value function at asset etc.
	! try using "golden" minimisation routine - does not require derivatives

if(age.eq.nt+ret)then

	if(bequest.lt.0.000001d0)then

		valueret = utility(partcash, hours,age, 1)	
		conret   = partcash
	
		utoday=valueret
		utomorrow=0.d0
	
	else
		aux = equival(age,1)*(bequest*equival(age,1))**(-1.d0/nu)
		conret = partcash*aux/(1.d0+aux)
		valueret = utility(conret, hours,age, 1) + bequest*utility(partcash-conret, 0.d0,age, 2)
	
	endif
	
	
else
    if(borrowdum.le.1) then 

	ax = minass/2.d0
	cx = max(partcash - minass*0.25d0,minass)				
	bx = cx*0.6d0

	valueret = golden(ax,bx,cx,retirefun,conret)

    valueret = - valueret 
    
    else
        conret		= partcash
	    valueret	= - retirefun(conret)
    
    endif
	
endif	



end subroutine valret

! ************************************************
subroutine valretW(valueretW,conretW)	 !solving for optimal consumption given not working

double precision conretW, valueretW, valuebit, aux
	
	!	in the non-work section, withnon = connon (avoids problem with fixed cost and value of leis

	!algorithm for solving for optimal value function at asset etc.
	! try using "golden" minimisation routine - does not require derivatives

if(age.eq.nt+ret)then

	if(bequest.lt.0.000001d0)then

		valueretW = utility(partcash, hours,age, 2)	
		conretW   = partcash
	
		utoday=valueretW
		utomorrow=0.d0
	
	else
		aux = equival(age,2)*(bequest*equival(age,2))**(-1.d0/nu)
		conretW = partcash*aux/(1.d0+aux)
		valueretW = utility(conretW, hours,age, 1) + bequest*utility(partcash-conretW, 0.d0,age, 2)
	
	endif
	
else
    if(borrowdum.le.1) then 

	ax = minass/2.d0
	cx = max(partcash - minass*0.25d0,minass)				
	bx = cx*0.6d0
	


	valueretW = golden(ax,bx,cx,retirefunW,conretW)

    valueretW = - valueretW 
    
    else
        conretW		= partcash
	    valueretW	= - retirefunW(conretW)
    
    endif
endif	
end subroutine valretW

! ************************************************
subroutine valretWh(valueretW,conretW)	 !solving for optimal consumption given not working

double precision conretW, valueretW, valuebit, aux
	
	!	in the non-work section, withnon = connon (avoids problem with fixed cost and value of leis

	!algorithm for solving for optimal value function at asset etc.
	! try using "golden" minimisation routine - does not require derivatives

if(age.eq.nt+ret)then

	if(bequest.lt.0.000001d0)then

		valueretW = utility(partcash, hours,age, 3)	
		conretW   = partcash
	
		utoday=valueretW
		utomorrow=0.d0
	
	else
		aux = equival(age,3)*(bequest*equival(age,3))**(-1.d0/nu)
		conretW = partcash*aux/(1.d0+aux)
		valueretW = utility(conretW, hours,age, 1) + bequest*utility(partcash-conretW, 0.d0,age, 2)
	
	endif
	
else
    if(borrowdum.le.1) then 

	ax = minass/2.d0
	cx = max(partcash - minass*0.25d0,minass)				
	bx = cx*0.6d0
	


	valueretW = golden(ax,bx,cx,retirefunWh,conretW)

    valueretW = - valueretW 
    
    else
        conretW		= partcash
	    valueretW	= - retirefunWh(conretW)
    
    endif
endif	
end subroutine valretWh


! ************************************************
subroutine valemp(value,withemp, leis)
double precision valuef, valuep, value, withempf, withempp, withemp, leisp, leisf, leis

    cash = partcash + wage*hoursfix -payrolltax(wage*hoursfix)- fixed(age)
    
    if(age.lt.nt.and.noexp.gt.1)then
		xtoemp = max(mapping(age,xvalue,1 ),1)  	
	else
		xtoemp = 1
	endif
	
	ax = min(minass*0.5d0, 0.5d0*(cash + mininc(xtoemp,age)))
	cx = cash + mininc(xtoemp,age)
	bx = cx*0.6d0

	if (borrowdum.le.1) then !ie saving (and maybe borrowing) are allowed 

		value = golden(ax,bx,cx,empfunhoursfix,withemp)

		if (withemp.ge.cx) then
			write (*,*) 'prob in optimial c emp'
		elseif (withemp.le.ax) then 
			write (*,*) 'prob in optima c emp too low '
		endif

		value = - value !solves for min of negative objective
		
		leis=hourseis

	else  !saving and borrowing not allowed

		withemp	 = cash
		value = - empfunhoursfix(withemp)
		leis=hourseis

	endif




end subroutine valemp





!*****************************************************

double precision function empfunhoursfix(con)
use summaryindex
double precision  cashtom, con, consto, estim1, estim4, experto,   expto, &
		intaet, intxet, leis, leisto, probhigh, problow, saving,  & 
		totvalue, utnow, valtobit2, valtobit2W, valtobit2Wh, valtom, vallow, valhigh, wagto, hourswk,wagef,piaf,penf, it1, it2


	integer  mina, nodeasbit, nodebit, nodebit2, node, nodeas, &
		nodebit2un, nodeasun, nxx, p, w, xmin, xtom, xx, penalty

	

	if(con.le.0.d0)then
		write(*,*)'neg cons',cash, totexpend, wage*leis,leis
	endif
	
	utnow = utility(con, hourseis,age, 1)
	hourswk = hoursfix 

	
	saving = detrr*(partcash + wage*hourswk - payrolltax(wage*hourswk) - con - fixed(age))

	totvalue = 0.d0


if(ageto.gt.nt)then !retirement is compulsory from age=nt+1, at this age husband is already retired, so spousal benefits can be c
	
	
	!because the individual was employed in t=nt I add one year of experience, so "expvalue(xvalue,age)+1" instead of "expvalue(xvalue,age)"
	!note that I cannot do "expvalue(xvalue+1,age)" because the following point in the grid could implied an increase of years of experience greater than 1
	call Cpiaf(xw(wnode,age),expvalue(xvalue,age)+1,piaf)  
	penf=pension(piaf,ageto)
	call findpension(penf,wnodepen,it1,it2)
	
	w=wnodepen
	xtom = 1 !ageto -ntmin
	penalty=5 !max(xtom, ntH+1 - ntmin)

	p=pnode
	leisto = hours
	
	!both alive
    cashtom	= saving + pxpen(p) + max(pxpen(p)*ssif(penalty),xpen(wnodepen))
	call find(ageto, cashtom, 1, mina, intaet, intxet, 2)
    node = sumindex(nmindex2,(/w,p,xtom,mina/))		
    estim1    = valr(node,ageto)     
    estim4    = valr(node+1, ageto)  
    valtobit2 = (intaet*estim1 + intxet*estim4)    					  				
	  
	!widow-female
	cashtom	= saving + max(pxpen(p)*survpen(penalty),xpen(wnodepen))
	call find(ageto, cashtom, 1, mina, intaet, intxet, 2)
    node = sumindex(nmindex2,(/w,p,xtom,mina/))
    		
    estim1    = valrW(node,ageto)     
    estim4    = valrW(node+1, ageto)  
    valtobit2W = (intaet*estim1 + intxet*estim4)    		
    
    !widow-male
	cashtom	= saving + pxpen(p)
	call find(ageto, cashtom, 1, mina, intaet, intxet, 2)
    node = sumindex(nmindex2,(/1,p,1,mina/))
    		
    estim1    = valrWh(node,ageto)     
    estim4    = valrWh(node+1, ageto)  
    valtobit2Wh = (intaet*estim1 + intxet*estim4)    					  				

	
	totvalue = valtobit2*psurv1(1)*psurv2(1) + valtobit2W*psurv2(1)*pdeath1(1)+&
	        &valtobit2Wh*psurv1(1)*pdeath2(1) + pdeath1(1)*pdeath2(1)*bequest*utility(saving,0.d0,age,2)
			
				
else
	experto = humancap(age, expvalue(xvalue,age) )
	xmin = mapping(age,xvalue,1)

	nxx=2
	if(noexp.ge.2)then	
		if (xmin.eq.0) then 
				xmin=1
				probhigh = 0.d0
				nxx=1
		elseif (xmin.eq.min(ageto,noexp)) then
				xmin=min(ageto,noexp)-1 
				probhigh = 1.d0
		elseif (xmin.lt.min(ageto,noexp)) then
				probhigh = 1.d0 - (expvalue(xmin+1,ageto) - experto) / & 
								(expvalue(xmin+1,ageto) - expvalue(xmin,ageto) ) 
		endif

	else
		xmin=1
		probhigh=0.d0
		nxx=1
	endif

	problow = 1.d0 - probhigh

	call futureval(xmin,nxx,saving,vallow,valhigh)
	totvalue= vallow*problow + valhigh*probhigh

endif !!!if ageto>nt


empfunhoursfix = - (utnow + totvalue*disc)


end function empfunhoursfix

!*****************************************************

subroutine futureval(xmin,nxx,saving,vlow,vhigh)

double precision  cashtom, con, consto, estim1, estim4, experto,   expto, &
		intaet, intxet, leis, leisto, probhigh, problow, probQ, saving,  & 
		totvalue, utnow, valtobit2, valtom, wagto, hourswk, minleis, vlow, vhigh,valtoe,valtou


	integer  finishw, finishp, mina, nodeasbit, nodebit, nodebit2, node, nodeas, &
		nodebit2un, nodeasun, nxx, p, startw, startp, trans, w, xmin, xtom, xx

vlow=0.d0  
vhigh=0.d0

do xx = 1, nxx


	expto  = expvalue(min(noexp,xmin + (xx-1),ageto), ageto) 
	xtom   = min(xmin + (xx-1),noexp,ageto)

	!now calculate expected value
	valtom  = 0.d0
	
	do w=1,nw
	
		valtobit2 = 0.d0
		do p=1,pnw

		    probQ=(1-quarter)*prob(w,p,wnode,pnode,ageto)+&
		                    &quarter*0.25d0*prob(w,p,wnode,pnode,ageto)
            
            if (dsolve(w,p,wnode,pnode,ageto).gt.0) then
						if(ageto.gt.ntH)then
							part		= pxpen(p)  
						else
							part		= pxw(p,ageto) 
						endif
						if(ageto.le.ntH)then  !only earnings pay taxes
							cashtom		= saving + part - payrolltax(part)
						else
							cashtom		= saving + part
						endif
						nodeas = sumindex(nmindex,(/w,p,xtom/))
						!if (cashtom.ge.asscut(nodeas,ageto)) then !not working
								!value of non working
								leisto = hours
								call find(ageto, cashtom, nodeas, mina, intaet, intxet, 0)
								node = sumindex(nmindex2,(/w,p,xtom,mina/))
		
								estim1    = valun(node,ageto)     
								estim4    = valun(node+1, ageto)  
								valtou    = intaet*estim1 + intxet*estim4
								!valtobit2 = valtobit2 + (intaet*estim1 + intxet*estim4)*probQ 
								
								
						!else	
								!value of working
								call find(ageto, cashtom, nodeas, mina, intaet, intxet,1)
								node = sumindex(nmindex2,(/w,p,xtom,mina/))

								estim1 = valemploy(node,ageto)     
								estim4 = valemploy(node+1, ageto)  
								valtoe    = intaet*estim1 + intxet*estim4
								!valtobit2 = valtobit2 + (intaet*estim1 + intxet*estim4)*probQ  
							
						!endif ! end work staus check
						valtobit2 = valtobit2 + max(valtoe,valtou)*probQ

				endif  !dsolve
				
			enddo !end partner

			valtom = valtom + valtobit2 
			

		enddo !end productivity loop
	

		if (xx.eq.1) vlow  = valtom 
		if (xx.eq.2) vhigh = valtom
	

	enddo !end experience loop
	


end subroutine futureval



!*****************************************************
double precision function unempfun(conun)
use summaryindex

	double precision cashtom, conun, consto, estim1, estim4, &
		experto, expto, intaet,  intxet, leisto, probhigh, problow, saving, & 
		totvalue, utnow, valtobit2, valtobit2W, valtobit2Wh,  valtom, vallow, valhigh,&
		wagto,wagef,penm,probtot, piaf, penf, it1, it2

	integer mina, node,nodebit, nodebit2, nodeas, nodeasbit, &
				nodebit2un, nodeasun, nxx, p, xmin, xtom, xx, w, penalty

	utnow = utility(conun, hours,age, 1)
	
	if(conun.le.0.d0)then
		write(25,*)'neg cons unemp',cash
	endif
		
	saving = detrr*(cash - conun)


	totvalue = 0.d0

if(ageto.gt.nt)then  !if you do not work at age>=nt retirement is compulsory from that age and you claim pension  

	
	call Cpiaf(xw(wnode,age),expvalue(xvalue,age),piaf)
	penf=pension(piaf,ageto)
	call findpension(penf,wnodepen,it1,it2)
		
	
	w = wnodepen
    p = pnode
	xtom = 1 !ageto -ntmin
	penalty=5 !max(xtom, ntH+1 - ntmin)
	leisto = hours
	

	!both alive
    cashtom	= saving + pxpen(p) + max(pxpen(p)*ssif(penalty),xpen(wnodepen))
	call find(ageto, cashtom, 1, mina, intaet, intxet, 2)	
	node = sumindex(nmindex2,(/w,p,xtom,mina/))
    estim1    = valr(node,ageto)     
    estim4    = valr(node+1, ageto)  
    valtobit2 = (intaet*estim1 + intxet*estim4)    					  				
	  
	!widow-female
	cashtom	= saving + max(pxpen(p)*survpen(penalty),xpen(wnodepen))
	call find(ageto, cashtom, 1, mina, intaet, intxet, 2)
    node = sumindex(nmindex2,(/w,p,xtom,mina/))	
    estim1    = valrW(node,ageto)     
    estim4    = valrW(node+1, ageto)  
    valtobit2W = (intaet*estim1 + intxet*estim4)    
    
    !widow-male
	cashtom	= saving + pxpen(p)
	call find(ageto, cashtom, 1, mina, intaet, intxet, 2)
    node = sumindex(nmindex2,(/1,p,1,mina/))	
    estim1    = valrWh(node,ageto)     
    estim4    = valrWh(node+1, ageto)  
    valtobit2Wh = (intaet*estim1 + intxet*estim4) 					  				

	
	totvalue = valtobit2*psurv1(1)*psurv2(1)+valtobit2W*psurv2(1)*pdeath1(1)+&
	        &valtobit2Wh*psurv1(1)*pdeath2(1) + pdeath1(1)*pdeath2(1)*bequest*utility(saving,0.d0,age,2)
			
	
    				
else

	experto = expvalue(xvalue,age) * (1.d0 - deltaperF(expvalue(xvalue,age)))

	xmin = mapping(age,xvalue,0)

	nxx=2

	if(noexp.gt.2)then	
		if (xmin.eq.0) then
					xmin=1
					probhigh = 0.d0
					nxx=1
		elseif (xmin.eq.min(ageto,noexp)) then 
					xmin=min(ageto,noexp)-1
					probhigh = 1.d0
		elseif (xmin.lt.min(ageto,noexp)) then
					probhigh = 1.d0 - (expvalue(xmin+1,ageto) - experto) / & 
							(expvalue(xmin+1,ageto) - expvalue(xmin,ageto) ) 
		endif
	else
		xmin=1
		probhigh=0.d0
		nxx=1
	endif

	problow = 1.d0 - probhigh
														 
	
	call futureval(xmin,nxx,saving,vallow,valhigh)

	totvalue= vallow*problow + valhigh*probhigh

endif !!!if ageto>nt

	unempfun = - (utnow + totvalue*disc)

    utoday=utnow
    utomorrow=totvalue

end function unempfun

!*****************************************************
double precision function retirefun(conun)
use summaryindex

double precision cashtom, conun, consto, estim1, estim4, &
	experto, expto, intaet,  intxet, leisto, probhigh, problow, saving, & 
	totvalue, utnow, valtobit2, valtobit2W, valtobit2Wh, valtom, &
	wagto,wagef,piaf,probtot,penm

integer mina, node,nodebit, nodebit2, nodeas, nodeasbit, &
			nodebit2un, nodeasun, p, xmin, xtom, xx, w, penalty
			
			

utnow = utility(conun, hours,age, 1)

if(conun.le.0.d0)then
	write(25,*)'neg cons retirefun',cash
endif
	
saving = detrr*(partcash - conun)
totvalue = 0.d0
valtom  = 0.d0

w = wnodepen
xtom=1 !xvalue
p = pnode
leisto = hours

penalty=5 !max(xtom, ntH+1 - ntmin)

if(ageto.gt.nt)then
!both alive
cashtom	= saving + pxpen(p) + max(pxpen(p)*ssif(penalty),xpen(wnodepen))

call find(ageto, cashtom, 1, mina, intaet, intxet, 2)
node = sumindex(nmindex2,(/w,p,xtom,mina/))
		
estim1    = valr(node,ageto)     
estim4    = valr(node+1, ageto)  
valtobit2 = (intaet*estim1 + intxet*estim4)    					  				

  
!widow-female
cashtom	= saving +  max(pxpen(p)*survpen(penalty),xpen(wnodepen))
call find(ageto, cashtom, 1, mina, intaet, intxet, 2)
node = sumindex(nmindex2,(/w,p,xtom,mina/))
		
estim1    = valrW(node,ageto)     
estim4    = valrW(node+1, ageto)  
valtobit2W = (intaet*estim1 + intxet*estim4)

!widow-male
cashtom	= saving +  pxpen(p)
call find(ageto, cashtom, 1, mina, intaet, intxet, 2)
node = sumindex(nmindex2,(/1,p,1,mina/))
		
estim1    = valrWh(node,ageto)     
estim4    = valrWh(node+1, ageto)  
valtobit2Wh = (intaet*estim1 + intxet*estim4)    					  				


retirefun = -(utnow + disc*(valtobit2*psurv1(ageret+1)*psurv2(ageret+1)+&
					   &valtobit2W*psurv2(ageret+1)*pdeath1(ageret+1)+&
					   &valtobit2Wh*psurv1(ageret+1)*pdeath2(ageret+1) +&
					   & pdeath1(ageret+1)*pdeath2(ageret+1)*bequest*utility(saving,0.d0,age,2)))
					   
					   
					   
else  !both alive

	if(ageto.gt.ntH)then !husband is retired
	
		cashtom	= saving + pxpen(p) + max(pxpen(p)*ssif(penalty),xpen(wnodepen))

		call find(ageto, cashtom, 1, mina, intaet, intxet, 2)
		node = sumindex(nmindex2,(/w,p,xtom,mina/))
				
		estim1    = valr(node,ageto)     
		estim4    = valr(node+1, ageto)  
		valtobit2 = (intaet*estim1 + intxet*estim4) 
		
		retirefun = -(utnow + disc*valtobit2)
	
	else  !husband is working
		valtobit2 =0.d0

		do p=1,pnw
			probtot=sum(prob(1:nw,p,wnodepen,pnode,ageto)) 
			cashtom	= saving + pxw(p,ageto) - payrolltax(pxw(p,ageto)) + xpen(wnodepen)

			call find(ageto, cashtom, 1, mina, intaet, intxet, 2)	
			node = sumindex(nmindex2,(/w,p,xtom,mina/))
			estim1    = valr(node,ageto)     
			estim4    = valr(node+1, ageto)  
			
			valtobit2 = valtobit2  + (intaet*estim1 + intxet*estim4)  *probtot
	    enddo
		
		retirefun = -(utnow + disc*valtobit2)
	
	endif
	
endif
	
end function retirefun

!*****************************************************
double precision function retirefunW(conun)
use summaryindex

	double precision cashtom, conun, consto, estim1, estim4, &
		experto, expto, intaet,  intxet, leisto, probhigh, problow, saving, & 
		totvalue, utnow, valtobit2W, valtom, &
		wagto,wagef,piaf

	integer mina, node,nodebit, nodebit2, nodeas, nodeasbit, &
				nodebit2un, nodeasun, p, xmin, xtom, xx, w

	utnow = utility(conun, hours,age, 2)
	
	if(conun.le.0.d0)then
		write(25,*)'neg cons retirefunW',cash
	endif
		
	saving = detrr*(partcash - conun)
	totvalue = 0.d0
	valtom  = 0.d0
	
	w = wnodepen
    xtom = xvalue
    p = pnode
	
	
	cashtom	= saving + max(pxpen(p)*survpen(xtom),xpen(wnodepen))

    leisto = hours
    
    call find(ageto, cashtom, 1, mina, intaet, intxet, 2)
    
    node = sumindex(nmindex2,(/w,p,xtom,mina/))
    		
     	
    estim1    = valrW(node,ageto)     
    estim4    = valrW(node+1, ageto)  
    valtobit2W = (intaet*estim1 + intxet*estim4)    					  				

    

    retirefunW = - (utnow + disc*(valtobit2W*psurv2(ageret+1)+ pdeath2(ageret+1)*bequest*utility(saving,0.d0,age,2)))
	
end function retirefunW

!*****************************************************
double precision function retirefunWh(conun)
use summaryindex

	double precision cashtom, conun, consto, estim1, estim4, &
		experto, expto, intaet,  intxet, leisto, probhigh, problow, saving, & 
		totvalue, utnow, valtobit2Wh, valtom, &
		wagto,wagef

	integer mina, node,nodebit, nodebit2, nodeas, nodeasbit, &
				nodebit2un, nodeasun, p, xmin, xtom, xx, w

	utnow = utility(conun, hours,age, 3)
		
	if(conun.le.0.d0)then
		write(25,*)'neg cons retirefunWh',cash
	endif	
		
	saving = detrr*(partcash - conun)
	totvalue = 0.d0
	valtom  = 0.d0
	
	
	w = 1 !wnode
    xtom = 1 !xvalue
    p = pnode
	
    leisto = hours
	
	cashtom	= saving + pxpen(p)
    
    call find(ageto, cashtom, 1, mina, intaet, intxet, 2)
    
    node = sumindex(nmindex2,(/w,p,xtom,mina/))
    		
     	
    estim1    = valrWh(node,ageto)     
    estim4    = valrWh(node+1, ageto)  
    valtobit2Wh = (intaet*estim1 + intxet*estim4)    					  				

    

    retirefunWh = - (utnow + disc*(valtobit2Wh*psurv1(ageret+1) + pdeath1(ageret+1)*bequest*utility(saving,0.d0,age,2)))
	
end function retirefunWh

end module equations
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!
