
clear matrix
clear
set more off
capture log close
set mem 200m


local file "R1"


************************************************************************************************************************************

infile i t yrsexp stat couple retage agekid ntH experien saving earnm partcash wagef cons socsecm piaf pf socsecf penf euler2 taxm taxf using sample`file'.out


replace stat=0 if pf>0 & stat>0


gen nt=41
gen firstretage=62
gen offage=66
gen lastretage=66
gen lastworkage=65

gen lastworkageH=ntH + 24
gen firstretageH=ntH+1 + 24


gen nc=35
gen k1= 8463
gen k2= 51584
gen Emax= 101959
gen ssif=0.5
gen survpen=1.0
gen omega1=0.9
gen omega2=0.32
gen omega3=0.15



gen age= t + 24

gen agekid2=agekid+3
gen years1=t- agekid
gen years2=t- agekid2

gen child04=0
gen child517=0
replace child04   =1 if years1>=0 & years1<5
replace child517 =1 if years1>=5 & years1<18
replace child04    =child04   +1 if years2>=0 & years2<5
replace child517  =child517 +1 if years2>=5 & years2<18
gen child=child04+child517

gen ageg2=1 if age<35
replace ageg2=2 if age>=35 & age<55
replace ageg2=3 if age>=55 & age<65
replace ageg2=4 if age>=65 & age<75
replace ageg2=5 if age>=75 



*retirement age
*sort i t
*by i:gen aux=age if retage==1 & retage[_n-1]==0
*by i:egen ageret=min(aux)
*drop aux
gen ageret=lastretage

*type of pension
gen tipoMARR=1 if pf>=socsecf & couple==1 & age>=ageret
replace tipoMARR=2 if pf>0 & pf<socsecf & couple==1 & age>=ageret
replace tipoMARR=3 if pf==0 & couple==1 & age>=ageret

gen tipoWID=1 if pf>=socsecf & couple==2 & age>=ageret
replace tipoWID=2 if pf>0 & pf<socsecf & couple==2 & age>=ageret
replace tipoWID=3 if pf==0 & couple==2  & age>=ageret

label define tipoMARRl 1 "worker" 2 "worker+spousal" 3 "spousal" 
label values tipoMARR tipoMARRl
label define tipoWIDl 1 "worker" 2 "worker+spousal" 3 "spousal" 
label values tipoWID tipoWIDl

save sample`file'.dta,replace


************************************************************************************************************************************




log using sample_`file'.log,replace



*recover husband shock
*0.05d0      !earnings growth for primary earner                              
*-0.00044d0   !earnings growth for primary earner 
gen a1=0.05
gen a2=-0.00044
gen hgrowth=exp(a1*age+a2*age*age)
gen pxw=earnm/hgrowth if age<=lastworkageH


gen obswage=wagef if stat==1
gen wagem=earnm/2000

*recover wive shock
gen xw=wagef/exp(0.01*(experien-1)-0.00014*(experien-1)*(experien-1))


gen earnf=wagef*2000 if stat==1
replace earnf=0 if stat==0

gen learnm=log(earnm)
gen lwagef=log(wagef)
gen lwagem=log(wagem)

gen inc=earnf + earnm






****************************************************************************************************
*LABOUR MARKET
****************************************************************************************************


*participation
sum stat if age>=25 & age<=64
sum stat if age>=25 & age<=29
sum stat if age>=30 & age<=34
sum stat if age>=55 & age<=59
sum stat if age>=60 & age<=65

sort age
table age,c(mean stat)


egen male=mean(earnm/2000) if age>=25 & age<=lastworkageH
egen female=mean(wagef) if stat==1 &age>=25 &  age<=lastworkageH
gen gap=female/male 
sum gap 



sort i t
by i:gen aux=sum(stat)
by i:gen totstat=aux[_N]
gen Itotstat=(totstat>0)


*years of experience
sum yrsexp  Itotstat if t==nt
sum yrsexp if t==nt & totstat>1,d
tab yrsexp if t==nt



*FEMALE AGE OF RETIRMENT DISTRIBUTION (FOR THOSE WHO ARE ELIGIBLE)

*age retirement
tab ageret if experien>10 & age==offage

*correlation of husband and wife age of retirement
tab ntH ageret if experien>10 & age==offage,col row

gen jretirement=(ageret==firstretageH) if experien>10 & age==offage

tab jretirement

*experience and other statistics by age of retirement

preserve
keep if  experien>10 & age==offage
sort ageret
table ageret, c(mean piaf mean pf mean socsecm mean totstat )
table ageret, c(mean saving median saving mean experien mean wagef)
restore




**********************************************************************************************************************
*FEMALE PENSION TYPE AND PENSIONS DISTRIBUTION

preserve
keep if age>=ageret

*MARRIED WOMEN (to compare with CPS) TYPE OF PENSION
tab tipoMARR if couple==1

*WIDOW WOMEN (to compare with CPS) TYPE OF PENSION
tab tipoWID if couple==2

*MARRIED WOMEN (to compare with CPS) PENSION DISTRIBUTION BY TYPE OF PENSION
sum socsecf,d
sum socsecf if couple==1 & tipoMARR==1,d
sum socsecf if couple==1 & tipoMARR>1,d


*WIDOWS PENSION DISTRIBUTION 
sum socsecf if  couple==2 ,d

*FRACTION OF WIDOWS WITHOUT PENSION
gen Isocsecf=(socsecf>0) 
sort couple
by couple:tab Isocsecf if age>=offage

restore

****************************************************************************************************
*INEQUALITY 
****************************************************************************************************

preserve

gen socsec=socsecm+socsecf

keep if t>nt
ineqdec0 socsec
ineqdec0 cons
ineqdec0 socsec if couple==1 
ineqdec0 socsec if couple==2
ineqdec0 socsec if couple==3



restore




log close

*end














