

module wageproc

! module giving wage process given variance on
! permanent and transitory components

use params

implicit none

double precision  normen, norvar, stdevw, pnormen, pnorvar, pstdevw 

double precision, allocatable :: contot(:,:,:,:,:)
double precision, allocatable ::  xw(:,:), yy(:), pyy(:)


double precision, allocatable :: pcumtrw(:)
double precision, allocatable :: trxw(:), ptrxw(:), cumtrw(:)
double precision, allocatable :: trweig(:), ptrweig(:), expvalue(:,:), expexpvalue(:,:)

double precision, allocatable, private :: absc(:), weig(:), sumprob(:), abscis(:), weigs(:)
double precision, allocatable, private :: pabscis(:), pweigs(:), trweigs(:), ptrweigs(:)
double precision, allocatable, private :: trabsc(:), ptrabsc(:),trwe(:), ptrwe(:), trabscis(:)
double precision, allocatable, private :: whigh(:), wlow(:), pwhigh(:), pwlow(:), ptrabscis(:)
double precision, allocatable, private :: pabsc(:), pweig(:), psumprob(:)

integer, allocatable :: dsolve(:,:,:,:,:), totdsolv(:,:)

integer, private :: i, ifail, irule, itype, jj, jl, jm, ju, nfix, p, pp, t, w, ww, wn, x

double precision, private :: aa, bb,   cconst, const2, dz,  hk, meanshk, qxfix(1), piam, &
    pweight, rhomult, sdz, summed, total, weight, xpri, sdzp, meanshkp ,  &
    aaint, bbint, errrel, errabs, errest, dzp, total2,aux


double precision :: constinteg, expinteg, transw, transw1, transp, transp1, wagecorr, cconst1, cconst2, mid



!external dnordf

contains

    subroutine allocate_wageproc_perm( iret )
        implicit none
        integer, intent(out)    :: iret
        integer                             :: ier(5)

       

	allocate (contot(nw,pnw,nw,pnw,nt), &
                 xw(nw,maxntinp),  xpen(nw), pxpen(pnw), expvalue(noexp,maxntinp), &
                expexpvalue(noexp,maxntinp), yy(maxntinp), stat = ier(1) )

				

    allocate (dsolve(nw,pnw,nw,pnw,totlen), totdsolv(nw,pnw), stat = ier(2) )
	allocate ( pyy(maxntinp), stat = ier(3) )

      

        do i=1,4
            if ( ier(i) .ne. 0) then
                iret = -i
                return
            endif
        enddo

        iret = 0

    end subroutine allocate_wageproc_perm

    subroutine allocate_wageproc_temp( iret )
        implicit none
        integer, intent(out)    :: iret
        integer  :: ier(2)

        allocate (absc(nw), abscis(nw), weigs(nw), sumprob(nw), &
            whigh(maxntinp), wlow(maxntinp), weig(nw), stat = ier(1) )

        do i=1,2
            if ( ier(i) .ne. 0) then
                iret = -i
                return
            endif
        enddo

        iret = 0

    end subroutine allocate_wageproc_temp

    subroutine deallocate_wageproc_temp( iret )
        implicit none
        integer, intent(out)    :: iret
        integer  :: ier(2)

        deallocate (absc, abscis, weigs, sumprob, whigh, wlow, weig,stat = ier(1) )


        do i=1,2
            if ( ier(i) .ne. 0) then
                iret = -i
                return
            endif
        enddo

        iret = 0

    end subroutine deallocate_wageproc_temp



    subroutine allocate_partproc_temp( iret )
        implicit none
        integer, intent(out)    :: iret
        integer  :: ier(2)

        allocate (pabsc(pnw), pabscis(pnw), pweigs(pnw), psumprob(pnw), &
                pweig(pnw), pwlow(maxntinp), pwhigh(maxntinp), stat = ier(1) )


        do i=1,2
            if ( ier(i) .ne. 0) then
                iret = -i
                return
            endif
        enddo

        iret = 0

    end subroutine allocate_partproc_temp

    subroutine deallocate_partproc_temp( iret )
        implicit none
        integer, intent(out)    :: iret
        integer  :: ier(2)

        deallocate (pabsc, pabscis, pweigs, pweig, pwlow, pwhigh, sumprob, stat = ier(1) )

        deallocate (ptrabsc, ptrwe, ptrabscis, ptrweigs,  stat = ier(2) )

        do i=1,2
            if ( ier(i) .ne. 0) then
                iret = -i
                return
            endif
        enddo

        iret = 0

    end subroutine deallocate_partproc_temp


!_______________________________________________________________________
  subroutine markovwagepr

 

			!!!!1-----exogenous wage growth with age, husband
			
            do t=1,nt
                if(quarter==0)then 
                    age = 24 + t
			    else
			        age= 24 + (t-1)/4
			    endif
                pyy(t) = exp(  page1 * dble(age) + page2 * dble(age)**2 )
				 
                
            enddo

			!!!!2-----human capital accumulation & exogenous wage growth with age, female
			!human capital (depends on values of calibrated parameters): can chage in the iterations
			!of the calibration
            
            do t=1,nt 
                if(quarter==0)then
                    age = 24 + t
			    else
			        age = 24 + (t-1)/4
			    endif
                            
                  if(noexp==1.OR.oleta0<0.0001d0)then
                    !exogenous growth for females also (same as male) 
                    yy(t) = exp(  age1 * dble(age) + age2 * dble(age)**2 )
                  
                  else
                    !endogenous growth for female wages through participation
                    yy(t) = 1.d0
                  endif
    
                  if (t.eq.frischt) then 
                    yy(t) = yy(t)*wagevar
                  endif
            enddo


            !!!!3-----grid for experience
			if(noexp.lt.2)then  
				expvalue=0.d0

			else

				do x =1,noexp
					expvalue(x,1) = 1.d0
				enddo
				
				do t=2,nt
				
				if(t.le.noexp)then
					expvalue(1,t) =expvalue(1,t-1) *(1.d0 - deltaperF(expvalue(1,t-1)))
					do x =2,t
						expvalue(x,t) = expvalue(x-1,t)+ 1.d0
					enddo
					
					!write(88,*)t, expvalue(:,t)
					
					write(88,*)''
					
				else
					expvalue(1,t) = expvalue(1,t-1) *(1.d0 - deltaperF(expvalue(1,t-1)))
					expvalue(noexp,t) = humancap(t-1, expvalue(noexp,t-1) ) 
				
					cconst = (expvalue(noexp,t)-expvalue(1,t))*0.3d0/dble(noexp-6)
					
					do x =2,noexp-6
						expvalue(x,t) = expvalue(1,t) + cconst * dble(x-1)
					enddo
					
					do x =noexp-5,noexp-1
						expvalue(x,t) =expvalue(noexp-6,t) + (expvalue(noexp,t)- expvalue(noexp-6,t))*(x-noexp+6)/6.d0
					enddo
					
					
					write(88,*)t, expvalue(:,t)
					
					write(88,*)''
					
				
				
				endif
				
				enddo

			endif 
			

            if(nw.gt.1.and.pnw.gt.1)then
			
			!!-HUSBAND RETIRES AT t=ntH and there is not uncertainty on his earnings afterwards
			do t=ntH,nt	
			!2-this is to change transition matrix so that the same state repits tomorrow 
			do w=1,nw !state today
			do p=1,pnw !state today
			do ww=1,nw !state tomorrow

				aux=sum(prob(ww,1:pnw,w,p,t))
				prob(ww,1:pnw,w,p,t)=0.d0
				prob(ww,p,w,p,t)=aux
				
			enddo
			enddo
			enddo	
			enddo
              
			  
			!!-ADJUST PROBABILITITIES AND BUILD dsolve ARRAY TO SPEED COMPUTATION 
          
            do t=1,nt
 	            do w=1,nw
		            do p=1,pnw

						!now adjust because of probability of no -update
			            total2 = 0.d0 
                        do ww=1,nw
                            do pp=1,pnw
			                    
					            if(prob(ww,pp,w,p,t)<1.d-5)then
						                dsolve(ww,pp,w,p,t) = 0
										prob(ww,pp,w,p,t) = 0.d0 

						        else	
						                dsolve(ww,pp,w,p,t) = 1
						              	total2 = total2 + prob(ww,pp,w,p,t)
    					        endif


		                enddo !end pp
                        enddo !end ww

			            total = 0.d0 
                        do ww=1,nw
                            do pp=1,pnw
								prob(ww,pp,w,p,t) = prob(ww,pp,w,p,t)/total2
			                    total = total + prob(ww,pp,w,p,t)
			                    contot(ww,pp,w,p,t) = total
			                enddo !end pp
                        enddo !end ww
						
			

                   enddo !end p    
	            end do  !end w   
        enddo !end t

		do t=nt+1,nt+ret
			dsolve(:,:,:,:,t) = 1
		enddo
		
		else
		do t=1,nt
            absc(1) = 1.d0
            prob(1,1,1,1,t) = 1.d0
            contot(1,1,1,1,t) = 1.d0
            dsolve(1,1,1,1,t) = 1
        enddo
		
		endif  !nw,pnw>1
		
		
		

	!!!!HUSBAND WAGES: pxw may be read or calculated above, then we add the WAGE GROWTH here
    do t=1,nt

        if (pnw.gt.1) then
            do w=1,pnw
                
               
                   !NOTE: pxw2 are earnings assuming 2000 hours. We changed average husband earnings to 2190
                   !so we need to do here the adjustment!
                    pxw3(w,t) = pxw2(w,t)*pyy(t)*meanearn*phoursfix/2000.d0
					
					
            enddo
        else

            pxw3(1,t) = meanearn*phoursfix*pyy(t)  
        
        endif
		
		
    enddo
	
	 do t=1,ntH
		do p=1,pnw
			pxw(p,t) = pxw3(p,t) 
		enddo 	
	enddo
	
	!!!!HUSBAND PENSION pxpen()
	do p=1,pnw
		!pxw(p,t)=pxw2(p,ntH)
		!NOTA: pxw2(p,ntH) es el shock SIN la acumulacion de capital humano
		call Cpiam(pxw(p,ntH),piam)
		pxpen(p)=pensionHUS(piam)
	enddo




	!!!!FEMALE WAGES: 
	!xww may be read or calculated above, then we add the WAGE GROWTH here & GENDER GAP
    !meanwage can change in the iterations of the calibration
    !!!meanwage = iniggap*pxw(max(pnw/2,1),1)/(expvalue(1,1)*hoursfix) 
    
    !multiply by meanearn as this was done for pxw in WageGrid.f90
    !multiply by iniggap to account for the offered wage gender gap 
   
   if(noexp.lt.2)then
      meanwage = iniggap*meanearn*pxw3(max(pnw/2,1),1)/(pyy(1)*phoursfix)
   else
      !meanwage = iniggap*meanearn*pxw(max(pnw/2,1),1)/(expvalue(1,1)*hoursfix)
	  meanwage = iniggap*pxw3(max(pnw/2,1),1)/phoursfix
	 
   endif
      
   
 
   
	do t=1,maxntinp
		if (nw.gt.1) then
			do w=1,nw
				xw(w,t) = xww(w,t)*meanwage *yy(t)			
			enddo
		else
			xw(1,t) = meanwage *yy(t)
		
		endif

    enddo	

    
   
	
	

  
    end subroutine markovwagepr


!__________________________________________________________________

double precision function humancap(hage, hkap)
integer hage, actualage
double precision hkap, loghumancap, acthours

    !alternative 1: age is what matters for the accumulation 
!!!    if(quarter.eq.0)then
!!!        actualage = hage + 22
!!!    else
!!!        actualage  = (hage-1)/4 + 1 + 22
!!!    endif
!!!    
!!!  
!!!    if(hage.le.17)then
!!!        loghumancap =  alpha1*log(hkap)+ (quarter*0.25d0 + (1.d0-quarter))*max(log(1.d0 + oleta0  ),0.d0)
!!!    else
!!!        loghumancap =  alpha1*log(hkap)+ (quarter*0.25d0 + (1.d0-quarter))*max(log(1.d0 + oleta1  ),0.d0)    
!!!    endif
!!!
!!!	if(loghumancap<0.d0)write(*,*)'loghk<0',hage, hkap
!!!	
!!!	humancap =  exp(loghumancap)
	
	!alternative 2: number of years of experience
	humancap= hkap + 1.d0

end function humancap
!__________________________________________________________________


integer function mapping(hage, xxxval, status)
integer hage, status, xxxval, xmin
double precision experien, acthours

        if (status.eq.0.and.xxxval.eq.1) then
                mapping = 1
        elseif (status.eq.1.and.xxxval.eq.min(hage,noexp)) then 
                mapping = min(hage,noexp)
        else

            if (status.eq.0) then
                experien = expvalue(xxxval,hage)*(1.d0 - deltaperF(expvalue(xxxval,hage)))
            else

                !*********** change here *********************************
				
                experien = humancap(hage, expvalue(xxxval,hage) )

                !*********** change here *********************************
            endif

            jl=0
            ju=min(hage+1,noexp)+1
9812                    if (ju-jl.gt.1) then
                    jm = (ju+jl)/2
                    if (experien.gt.expvalue(jm,hage+1) ) then
                        jl = jm
                    else
                        ju = jm
                    endif
                    goto 9812
            endif
            xmin = jl
            !if (xmin.eq.noexp) then
            !    xmin = noexp - 1
            !elseif (xmin.eq.0) then
            !    xmin = 1
            !endif
			mapping = xmin
			!it is possible to have mapping=0, this will be considered as a possible case in empfun & unempfun
			!In the rest of places where mapping is called &  mapping=0 will be substituted by mapping=1

         endif

end function
!__________________________________________________________________

double precision function ryearsexp(hkap0)
double precision hkap0, hkap

hkap=hkap0-1.d0

ryearsexp = dexp(oleta0*hkap + oleta1*hkap*hkap)

end function


!______________________________________________
subroutine Cpiam (lastm,piam)
double precision avearnm, lastm,piam
integer cont,t

!!!!PIA HUSBAND
!average lifetime earnings (last nc years)
avearnm=0.d0
do t=ntH-nc,ntH
	avearnm=avearnm + ((lastm/pyy(ntH))*pyy(t))/real(nc)
enddo

!adjustment of PIA to reduce the variance
piam=exp(a0+a1*log(avearnm))

end subroutine Cpiam


!______________________________________________
subroutine Cpiaf (lastf,experien,piaf)
double precision avearnf, lastf,  experien, piaf,av,aux
integer cont,t


!!!!PIA WIFE
!average lifetime earnings (last nc years) wife

!adjustment to reduce the variance: average observed wage in the life-cycle as a function of last period wage 
av=exp(a0f+a1f*log(lastf))

if(experien.gt.10d0)then  !note that there is a minimun of 10 years contributions to be eligible 
    cont=int(experien)
    avearnf=0.d0
    if(cont.le.nc)then
        do t=1,max(1,cont)
			aux=real(t)
            avearnf=avearnf + av*hoursfix*ryearsexp(aux)/real(nc)
        enddo
    else
        do t=cont,cont-(nc-1),-1
			aux=real(t)
            avearnf=avearnf + av*hoursfix*ryearsexp(aux)/real(nc)
        enddo 
    endif
else
    avearnf=0.d0
endif

piaf=avearnf
!piaf=exp(a0+a1*log(avearnf))
end subroutine Cpiaf

!__________________________________________________________________

subroutine gridpension
double precision aux,penmin,years
integer w,t
	
	xpen(nw)=0.d0   										!non eligible
	xpen(1)=omega1*k1 + omega2*(k2-k1) + omega3*(Emax-k2)   !max pension
	
	penmin=0.d0
	!do t=1,10
	!	years=real(t)
	!	if(ntmin.lt.nt)then
	!		penmin=penmin+minval(xw(nw,ntmin+1:nt))*hoursfix*ryearsexp(years)/10.d0
	!	else
	!		penmin=penmin+xw(nw,nt)*hoursfix*ryearsexp(years)/10.d0
	!	endif
	!enddo
	xpen(nw-1)=2500.d0 !penmin
	
	aux=(xpen(1)-xpen(nw-1))/real(nw-2)
	
	do w=2,nw-2
		xpen(w)=xpen(w-1)- aux
	
	enddo
	
	if(ID.eq.0)write(*,*) xpen
	
	
end subroutine gridpension


end module wageproc



